==> material-react-table-2.0.1.tgz: package/locales/ja/index.esm.js <==
const MRT_Localization_JA = {
    actions: '操作',
    and: 'と',
    cancel: 'キャンセル',
    changeFilterMode: '検索モードを変更',
    changeSearchMode: '検索モードを変更',
    clearFilter: 'リセット',
    clearSearch: 'リセット',
    clearSort: '並べ替えを解除',
    clickToCopy: 'クリックでコピー',
    collapse: '折りたたむ',
    collapseAll: 'すべて折りたたむ',
    columnActions: '操作',
    copiedToClipboard: 'クリップボードにコピーしました',
    dropToGroupBy: 'ドロップで{column}をグループ化',
    edit: '編集',
    expand: '展開',
    expandAll: 'すべて展開',
    filterArrIncludes: '含む',
    filterArrIncludesAll: '全て含む',
    filterArrIncludesSome: '含む',
    filterBetween: '最大最小',
    filterBetweenInclusive: '間を含む',
    filterByColumn: '{column}を検索',
    filterContains: '含まれる',
    filterEmpty: '空',
    filterEndsWith: 'で終わる',
    filterEquals: '一致',
    filterEqualsString: '一致',
    filterFuzzy: 'あいまい検索',
    filterGreaterThan: 'より大きい',
    filterGreaterThanOrEqualTo: '以上',
    filterInNumberRange: '間',
    filterIncludesString: '含む',
    filterIncludesStringSensitive: '含む',
    filterLessThan: 'より少ない',
    filterLessThanOrEqualTo: '以下',
    filterMode: '検索モード:{filterType}',
    filterNotEmpty: '空ではない',
    filterNotEquals: '不一致',
    filterStartsWith: 'で始まる',
    filterWeakEquals: '等しい',
    filteringByColumn: '{column}によるフィルタリング - {filterType}{filterValue}',
    goToFirstPage: '最初のページへ移動',
    goToLastPage: '最後のページへ移動',
    goToNextPage: '次のページへ移動',
    goToPreviousPage: '前のページに移動',
    grab: '掴む',
    groupByColumn: '{column}をグループ化',
    groupedBy: 'グループ化',
    hideAll: '全て隠す',
    hideColumn: '{column}を隠す',
    max: '最大',
    min: '最小',
    move: '移動',
    noRecordsToDisplay: '表示するレコードがありません',
    noResultsFound: '結果なし',
    of: '/',
    or: 'または',
    pin: '固定',
    pinToLeft: '左に固定',
    pinToRight: '右に固定',
    resetColumnSize: '列のサイズをリセット',
    resetOrder: '並べ替えをリセット',
    rowActions: '行の操作',
    rowNumber: 'No.',
    rowNumbers: '行番号',
    rowsPerPage: '表示件数',
    save: '保存',
    search: '検索',
    selectedCountOfRowCountRowsSelected: '{rowCount}行中{selectedCount}行が選択されました',
    select: '選択',
    showAll: '全て表示',
    showAllColumns: 'すべての列を表示',
    showHideColumns: '列の表示状態',
    showHideFilters: '検索バーを表示',
    showHideSearch: '検索',
    sortByColumnAsc: '{column}を昇順でを並べ替え',
    sortByColumnDesc: '{column}を降順でを並べ替え',
    sortedByColumnAsc: '{column}を昇順でを並べ替え',
    sortedByColumnDesc: '{column}を降順でを並べ替え',
    thenBy: 'さらに',
    toggleDensity: 'テーブルの高さを変更',
    toggleFullScreen: 'フルスクリーン切り替え',
    toggleSelectAll: 'すべて選択',
    toggleSelectRow: '選択',
    toggleVisibility: '表示を切り替え',
    ungroupByColumn: '{column}のグループ解除',
    unpin: '固定を解除',
    unpinAll: 'すべての固定を解除',
};

export { MRT_Localization_JA };

==> material-react-table-2.9.1.tgz: package/locales/ja/index.esm.js <==
const MRT_Localization_JA = {
    actions: '操作',
    and: 'と',
    cancel: 'キャンセル',
    changeFilterMode: '検索モードを変更',
    changeSearchMode: '検索モードを変更',
    clearFilter: 'リセット',
    clearSearch: 'リセット',
    clearSort: '並べ替えを解除',
    clickToCopy: 'クリックでコピー',
    collapse: '折りたたむ',
    collapseAll: 'すべて折りたたむ',
    columnActions: '操作',
    copiedToClipboard: 'クリップボードにコピーしました',
    dropToGroupBy: 'ドロップで{column}をグループ化',
    edit: '編集',
    expand: '展開',
    expandAll: 'すべて展開',
    filterArrIncludes: '含む',
    filterArrIncludesAll: '全て含む',
    filterArrIncludesSome: '含む',
    filterBetween: '最大最小',
    filterBetweenInclusive: '間を含む',
    filterByColumn: '{column}を検索',
    filterContains: '含まれる',
    filterEmpty: '空',
    filterEndsWith: 'で終わる',
    filterEquals: '一致',
    filterEqualsString: '一致',
    filterFuzzy: 'あいまい検索',
    filterGreaterThan: 'より大きい',
    filterGreaterThanOrEqualTo: '以上',
    filterInNumberRange: '間',
    filterIncludesString: '含む',
    filterIncludesStringSensitive: '含む',
    filterLessThan: 'より少ない',
    filterLessThanOrEqualTo: '以下',
    filterMode: '検索モード:{filterType}',
    filterNotEmpty: '空ではない',
    filterNotEquals: '不一致',
    filterStartsWith: 'で始まる',
    filterWeakEquals: '等しい',
    filteringByColumn: '{column}によるフィルタリング - {filterType}{filterValue}',
    goToFirstPage: '最初のページへ移動',
    goToLastPage: '最後のページへ移動',
    goToNextPage: '次のページへ移動',
    goToPreviousPage: '前のページに移動',
    grab: '掴む',
    groupByColumn: '{column}をグループ化',
    groupedBy: 'グループ化',
    hideAll: '全て隠す',
    hideColumn: '{column}を隠す',
    max: '最大',
    min: '最小',
    move: '移動',
    noRecordsToDisplay: '表示するレコードがありません',
    noResultsFound: '結果なし',
    of: '/',
    or: 'または',
    pin: '固定',
    pinToLeft: '左に固定',
    pinToRight: '右に固定',
    resetColumnSize: '列のサイズをリセット',
    resetOrder: '並べ替えをリセット',
    rowActions: '行の操作',
    rowNumber: 'No.',
    rowNumbers: '行番号',
    rowsPerPage: '表示件数',
    save: '保存',
    search: '検索',
    selectedCountOfRowCountRowsSelected: '{rowCount}行中{selectedCount}行が選択されました',
    select: '選択',
    showAll: '全て表示',
    showAllColumns: 'すべての列を表示',
    showHideColumns: '列の表示状態',
    showHideFilters: '検索バーを表示',
    showHideSearch: '検索',
    sortByColumnAsc: '{column}を昇順で並べ替え',
    sortByColumnDesc: '{column}を降順で並べ替え',
    sortedByColumnAsc: '{column}を昇順で並べ替え',
    sortedByColumnDesc: '{column}を降順で並べ替え',
    thenBy: 'さらに',
    toggleDensity: 'テーブルの高さを変更',
    toggleFullScreen: 'フルスクリーン切り替え',
    toggleSelectAll: 'すべて選択',
    toggleSelectRow: '選択',
    toggleVisibility: '表示を切り替え',
    ungroupByColumn: '{column}のグループ解除',
    unpin: '固定を解除',
    unpinAll: 'すべての固定を解除',
};

export { MRT_Localization_JA };
